Crate keccak_cli_tool
keccak_
cli_
tool
0.1.1
All Items
Crate Items
Modules
Functions
Crate
keccak_
cli_
tool
Modules

hash
Functions

hash_
logic
Calculates and returns the Keccak256 hash of a vector of strings. If the string is a file, it reads the file and calculates the hash of the file (including newline chars).